#ifndef ___CONFIG_H___
#define ___CONFIG_H___

#define HAVE_UNISTD_H
#define HAVE_MALLOC_H
#define HAVE_STDBOOL_H
#define HAVE_ASPRINTF
/* #undef _DEBUG */
#define _ENABLE_DBUS
#define _ENABLE_PANGO
/* #undef _FCITX_DISABLE_GETTEXT */
#define ENABLE_OPENCC
/* #undef LIBKVM_FOUND */
#define HAVE_XINERAMA
#define HAVE_XFIXES
/* #undef LIBICONV_SECOND_ARGUMENT_IS_CONST */
#define ENABLE_SNOOPER
#define ENABLE_X11
#define ENABLE_XKB
#define ENABLE_BACKTRACE
#define NO_SNOOPER_APPS ".*chrome.*,.*chromium.*,firefox.*,Do.*"
#define NO_PREEDIT_APPS "gvim"
#define ISOCODES_ISO639_JSON ""
#define ISOCODES_ISO3166_JSON ""
#define XKEYBOARDCONFIG_XKBBASE "/usr/share/X11/xkb"
/* #undef XKB_RULES_XML_FILE */
/* #undef LIBICONV_SECOND_ARGUMENT_IS_CONST */
#define ENCHANT_FOUND
#define ENABLE_ENCHANT
/* #undef PRESAGE_FOUND */
#define ENABLE_PRESAGE
#define PRESAGE_LIBRARY_FILENAME "libpresage.so"
#define ENCHANT_LIBRARY_FILENAME "libenchant-2.so.2"
#define OPENCC_LIBRARY_FILENAME "libopencc.so.1.3"

#define PACKAGE "fcitx"
#ifdef FCITX_USE_INTERNAL_PATH
#define LOCALEDIR "/usr/share/locale"
#define DATADIR "/usr/share"
#define PKGDATADIR "/usr/share/fcitx"
#define BINDIR "/usr/bin"
#define LIBDIR "/usr/lib"
#endif

#ifdef ENABLE_SNOOPER
#define _ENABLE_SNOOPER 1
#else
#define _ENABLE_SNOOPER 0
#endif

#define VERSION "4.2.9.9"
#define INTERNAL_VERSION 3

#ifdef LIBICONV_SECOND_ARGUMENT_IS_CONST
typedef const char* IconvStr;
#else
typedef char* IconvStr;
#endif

#endif
