/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#ifndef __FCITX_MARSHALL_MARSHAL_H__
#define __FCITX_MARSHALL_MARSHAL_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* VOID:UINT,UINT,INT (/build/fcitx/src/fcitx-4.2.9.9/src/frontend/gtk-common/marshall.list:1) */
extern
void fcitx_marshall_VOID__UINT_UINT_INT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
                                         const GValue *param_values,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);

/* VOID:STRING,STRING,STRING (/build/fcitx/src/fcitx-4.2.9.9/src/frontend/gtk-common/marshall.list:2) */
extern
void fcitx_marshall_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:STRING,INT (/build/fcitx/src/fcitx-4.2.9.9/src/frontend/gtk-common/marshall.list:3) */
extern
void fcitx_marshall_VOID__STRING_INT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:BOXED,INT (/build/fcitx/src/fcitx-4.2.9.9/src/frontend/gtk-common/marshall.list:4) */
extern
void fcitx_marshall_VOID__BOXED_INT (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);

/* VOID:INT,UINT (/build/fcitx/src/fcitx-4.2.9.9/src/frontend/gtk-common/marshall.list:5) */
extern
void fcitx_marshall_VOID__INT_UINT (GClosure     *closure,
                                    GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint,
                                    gpointer      marshal_data);

/* VOID:STRING,STRING,STRING,STRING,STRING,INT (/build/fcitx/src/fcitx-4.2.9.9/src/frontend/gtk-common/marshall.list:6) */
extern
void fcitx_marshall_VOID__STRING_STRING_STRING_STRING_STRING_INT (GClosure     *closure,
                                                                  GValue       *return_value,
                                                                  guint         n_param_values,
                                                                  const GValue *param_values,
                                                                  gpointer      invocation_hint,
                                                                  gpointer      marshal_data);


G_END_DECLS

#endif /* __FCITX_MARSHALL_MARSHAL_H__ */
